tlslite.utils.compat

Package tlslite :: Package utils :: Module compat |
[show private | hide private]
[frames | no frames]

## Module tlslite.utils.compat

Miscellaneous functions to mask Python version differences.

Function Summary
| `bytesToString(bytes)`
| `concatArrays(a1, a2)`
| `createByteArraySequence(seq)`
| `createByteArrayZeros(howMany)`
| `formatExceptionTrace(e)`
| `numBits(n)`
| `stringToBytes(s)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net